/************************************************************************
*
* Copyright (C) 2001 by 
* Kerenyi Kristof, Toth Gergely
*
* Team Monica Javacom, Package version 0.2
*
* Report any comments to javacom@tg.sch.bme.hu
* 
* Available under the GPL.
* 
* For more details about the copyright terms and conditions read the
* GNU Public License (GPL) available under www.gnu.org/copyleft/gpl.txt.
* 
*********************************************************************** */


package com.monica.javacom.application;

import com.monica.javacom.interfaces.*;
import com.monica.javacom.transport.*;
import com.monica.javacom.ciphering.*;
import com.monica.javacom.manager.*;
import com.monica.javacom.protocol.*;
import com.monica.javacom.terminal.*;
import com.monica.javacom.virtualinput.*;
import com.monica.javacom.virtualdisplay.*;
import com.monica.javacom.window.*;
import com.monica.javacom.application.*;
import com.monica.javacom.util.*;

import java.io.*;
import java.awt.*;
import java.awt.event.*;

/** Class for implementing the client services of Team MONICA JavaCom.
    This class has to be run from the command line. <br><br>
    <b>Usage: java com.monica.javacom.application.MJCClient destHost destPort [logFile] </b><br><br>
    The configuration will be read from ./MJC.conf.
*/
public class MJCClient {

  /** Entry point for the JAVA VM.
      @param String[] args: the command line parameters
  */
  public static void main(String[] args) {
    if (args.length>=2) {

      // parsing cmdline

      String host=args[args.length-2];
      int port=Integer.parseInt(args[args.length-1]);
      boolean intro=true;

      if (args.length>2) {
        for (int i=0; i<(args.length-2); i++) {
          if (args[i].indexOf("-nointro")==0) intro=false;
          // if (args[i].indexOf("-log=")==0) log
        }
      }

      // setting up MJC layer hierarchy

      MJCConfiguration configuration=new MJCFileConfiguration();

      if (intro) {
        MJCIntro introW=new MJCIntro(configuration);
        introW.setVisible(true);
        try {
          (Thread.currentThread()).sleep(3000);
        }
        catch (Exception e) {
          e.printStackTrace();
        }
        introW.setVisible(false);
      }

      MJCTransport transport=new MJCTCPTransport();
      MJCCiphering ciphering=new MJCBasicCiphering(false);
      MJCManager manager=new MJCManager();
      MJCProtocol protocol=new MJCTelnetProtocol();
      MJCTerminal terminal=new MJCVT220Terminal();
      MJCVirtualDisplay display=new MJCAWTDisplay(configuration);
      MJCVirtualInput input=new MJCKeyListener();
      MJCWindow window=new MJCAWTWindow(display, configuration, (KeyListener)input);

      transport.setReader(ciphering);
      transport.setConfiguration(configuration);

      ciphering.setReadable(transport);
      ciphering.setReader(manager);
      ciphering.setWriteable(transport);
      ciphering.setConfiguration(configuration);

      manager.setReadable(ciphering);
      manager.setTransport(transport);
      manager.setWriteable(ciphering);
      manager.setReader(protocol);
      manager.setConfiguration(configuration);

/*      MJCConfigureable[] reconf=new MJCConfigureable[6];
      reconf[0]=transport;
      reconf[1]=ciphering;
      reconf[2]=terminal;
      reconf[3]=display;
      reconf[4]=input;
      reconf[5]=protocol;
      manager.setReconfigureable(reconf); */

      protocol.setReadable(manager);
      protocol.setWriteable(manager);
      protocol.setReader(terminal);
      protocol.setConfiguration(configuration);

      terminal.setReadable(protocol);
      terminal.setConfiguration(configuration);
      terminal.setWriteable(protocol);
      terminal.setVirtualDisplay(display);

      display.setConfiguration(configuration);

      window.setConfiguration(configuration);
      window.setCloser(manager);

      input.setConfiguration(configuration);
      input.setWriteable(terminal);

      ((Frame)window).setVisible(true);

      try {
        transport.initAsClient(host, port);
      }
      catch (Exception e) {
        display.clear();
        display.setCPos(0,0);
        display.addS("Connection to the server could not be established. Reason: "+e.toString());
        display.refresh();
      }

      Object o=new Object();
      try {
        synchronized (o) {
	        o.wait();
	      }
      }
      catch (Exception e) {
      }
    }
    else {
      System.out.println("Usage: ");
      System.out.println("java MJCClient destHost destPort [logFile]");
      System.exit(0);
    }
  }
}