/************************************************************************
*
* Copyright (C) 2001 by 
* Kerenyi Kristof, Toth Gergely
*
* Team Monica Javacom, Package version 0.2
*
* Report any comments to javacom@tg.sch.bme.hu
* 
* Available under the GPL.
* 
* For more details about the copyright terms and conditions read the
* GNU Public License (GPL) available under www.gnu.org/copyleft/gpl.txt.
* 
*********************************************************************** */


package com.monica.javacom.application;

import com.monica.javacom.interfaces.*;
import com.monica.javacom.protocol.*;
import com.monica.javacom.util.*;
import java.io.*;

/** Class for implementing the server services for the Team MONICA JavaCom.
    This class has to be run from the command line. <br><br>
    <b>Usage: java com.monica.javacom.application.MJCServer workPort forwardToHost forwardToPort adminPort [logFile] [confFile]</b><br><br>
*/
public class MJCServer {

  /** Entry point for the JAVA VM.
      @param String[] agrs: the command line parameters
  */
  public static void main(String[] args) {

    if (args.length<4) {
      System.out.println("Usage: ");
      System.out.println("java MJCServer workPort forwardToHost forwardToPort adminPort [logFile] [confFile]");
      System.exit(0);
    }

    MJCConfiguration configuration=new MJCFileConfiguration();

    MJCLoopBackProtocol lbp=new MJCLoopBackProtocol(
      Integer.parseInt(args[0]), //workport
      args[1], // forward to host
      Integer.parseInt(args[2]), // forward to port
      Integer.parseInt(args[3])); // admin port

    lbp.setConfiguration(configuration);

    try {
      if (args.length>4) {
        System.setOut(new PrintStream(new FileOutputStream(args[4],true)));
      }
    }
    catch (Exception e) {
      System.out.println(e.toString());
      System.exit(0);
    }

    try {
      if (args.length>5) {
        lbp.setConfigurationInput(args[5]);
      }
    }
    catch (Exception e) {
      System.out.println(e.toString());
      System.exit(0);
    }

    lbp.start();
  }

}