/************************************************************************
*
* Copyright (C) 2001 by 
* Kerenyi Kristof, Toth Gergely
*
* Team Monica Javacom, Package version 0.2
*
* Report any comments to javacom@tg.sch.bme.hu
* 
* Available under the GPL.
* 
* For more details about the copyright terms and conditions read the
* GNU Public License (GPL) available under www.gnu.org/copyleft/gpl.txt.
* 
*********************************************************************** */


package com.monica.javacom.ciphering;

import java.util.StringTokenizer;

/**	This is the key object used to the AES object, which implements the AES encription algorithm.
		This object is generated by an AESKeyGenerator.
		@see AESKeyGenerator
		@see AES
*/

public class AESKey {

	private int[] key;
	
/** 	Constructs a new AESKey object. This method is normally called by the AESKeyGenerator.
		@param in_key this includes the initial random numbers of the AESKey
*/	
	
	public AESKey(int[] in_key) {

		key=in_key;
	
	}

/** 	Constructs a new AESKey object. This method is normally called when a serialized form of the AESKey is given, this reconstructs the object.
		@param save this includes the serialized form of the AESKey
		@thorws LoadKeyException this occurs, when the input value is not recognized as an AESKey
*/	
	
	public AESKey(String save) throws LoadKeyException {

		try {
			int[] temp=new int[256];

			StringTokenizer stringTokenizer=new StringTokenizer(save);
			int i=0;
			while (stringTokenizer.hasMoreTokens())
				temp[i++]=Integer.parseInt(stringTokenizer.nextToken());
		   	key=new int[i];
		   	for(int j=0; j<i; j++)
	   			key[j]=temp[j];
	   	}
		catch (Exception e) {
			throw new LoadKeyException("AESKey: loading error: "+e);
		}
	
	
	}

/**	Returns a copy of the AESKey random numbers.
		@return the random numbers of the AESKey
*/	
	
	public int[] getKey() {
	
		return (int[])key.clone();
	
	}
	
/**	Returns the serialized String representation of the AESKey.
		@return the serialized form of the AESKey
*/
	
	public String toString() {
	
		String s=new String();


		for(int i=0; i<key.length; i++)
			s=s.concat(Integer.toString(key[i])+" ");
		
		return s;
	
	}

}
