/************************************************************************
*
* Copyright (C) 2001 by 
* Kerenyi Kristof, Toth Gergely
*
* Team Monica Javacom, Package version 0.2
*
* Report any comments to javacom@tg.sch.bme.hu
* 
* Available under the GPL.
* 
* For more details about the copyright terms and conditions read the
* GNU Public License (GPL) available under www.gnu.org/copyleft/gpl.txt.
* 
*********************************************************************** */


package com.monica.javacom.ciphering;

import java.util.Random;

/**	Realizes an AESKeyGenerator. This object is used to create a proper AESKey for using it in an AES encoder/decoder.
		The AESKey retruned by the generating function must be passed to the AES object.
		@see AESKey
		@see AES
*/

public class AESKeyGenerator {

	private int keyLength;
	private Random random;
	
/** 	Constructs a new AESKeyGenerator. If supplied with a proper Random object, it creates a secure AESKey.
		@param in_keyLength the keylength of the AESKey to be generated - default: 16
		@param in_random the Random object the AESKeyGenerator will use to generate the random numbers
		@throws BadInputValueException the in_keyLength must be between 4 and 255
*/	
	
	public AESKeyGenerator(int in_keyLength, Random in_random) throws BadInputValueException {

		if ((in_keyLength<4) || (in_keyLength>255)) throw new BadInputValueException("AESKeyGenerator: keyLength must be between 4 and 255");
		else keyLength=in_keyLength/4;
		
		random=in_random;

	}

/**	Generates a new AESKey with the given keyLength and Random object.
		@return a new AESKey with the given parameters
*/	
	
	public AESKey generateAESKey() {
	
		int[] key=new int[keyLength];
		for(int i=0; i<keyLength; i++)
			key[i]=random.nextInt();
			
		return new AESKey(key);	
	
	}
	
/**	Returns the keylength of the AESKey to be generated.
		@return the keylength of the AESKey
*/	
	
	public int getKeyLength() {
	
		return keyLength*4;
		
	}
	
/**	Sets the keylength of the AESKey to be generated.
		@param in_keyLength the keylength of the AESKey
		@throws BadInputValueException the in_keyLength must be between 4 and 255
*/	
	
	public void setKeyLength(int in_keyLength) throws BadInputValueException {
	
		if ((in_keyLength<4) || (in_keyLength>252)) throw new BadInputValueException("AESKeyGenerator: keyLength must be between 4 and 252");
		else keyLength=in_keyLength/4;
	
	}

}