/************************************************************************
*
* Copyright (C) 2001 by 
* Kerenyi Kristof, Toth Gergely
*
* Team Monica Javacom, Package version 0.2
*
* Report any comments to javacom@tg.sch.bme.hu
* 
* Available under the GPL.
* 
* For more details about the copyright terms and conditions read the
* GNU Public License (GPL) available under www.gnu.org/copyleft/gpl.txt.
* 
*********************************************************************** */


package com.monica.javacom.ciphering;

import java.math.BigInteger;
import java.util.StringTokenizer;

/**	This is the key object used to the RSA object, which implements the RSA encription algorithm.
		This object is part of an RSAKeyPair, generated by an RSAKeyPairGenerator.
		It consists of a modulus and an exponent, as defined in the RSA encsription algorithm.
		@see RSAKeyPair
		@see RSAKeyPairGenerator
		@see RSA
*/

public class RSAKey {

	private BigInteger modulus;
	private BigInteger exponent;

/** 	Constructs a new RSAKey object. This method is normally called by the program, splitting the RSAKeyPair in public and private parts.
		@param in_modulus this includes the modulus part of the RSAKey
		@param in_exponent this includes the exponent part of the RSAKey
*/	
	
	public RSAKey(BigInteger in_modulus, BigInteger in_exponent) {
	
		modulus = in_modulus;
		exponent = in_exponent;
	
	}

/** 	Constructs a new RSAKey object. This method is normally called when a serialized form of the RSAKey is given, this reconstructs the object.
		@param save this includes the serialized form of the RSAKey
		@thorws LoadKeyException this occurs, when the input value is not recognized as an RSAKey
*/	
	
	public RSAKey(String save) throws LoadKeyException {
		
		try {
			StringTokenizer stringTokenizer=new StringTokenizer(save);
	
			modulus=new BigInteger(stringTokenizer.nextToken());
			exponent=new BigInteger(stringTokenizer.nextToken());
		}
		catch (Exception e) {
			throw new LoadKeyException("RSAKey: loading error: "+e);
		}
		
	
	}
	
/**	Returns the modulus of the RSAKey.
		@return the modulus part of the RSAKey
*/	
	
	public BigInteger getModulus() {

		return modulus;

	}	

/**	Returns the exponent of the RSAKey.
		@return the exponent part of the RSAKey
*/	
	
	public BigInteger getExponent() {

		return exponent;		

	}

/**	Returns the serialized String representation of the RSAKey.
		@return the serialized form of the RSAKey
*/
	
	public String toString() {
	
		return new String(modulus.toString()+" "+exponent.toString());
	
	}

}