/************************************************************************
*
* Copyright (C) 2001 by 
* Kerenyi Kristof, Toth Gergely
*
* Team Monica Javacom, Package version 0.2
*
* Report any comments to javacom@tg.sch.bme.hu
* 
* Available under the GPL.
* 
* For more details about the copyright terms and conditions read the
* GNU Public License (GPL) available under www.gnu.org/copyleft/gpl.txt.
* 
*********************************************************************** */


package com.monica.javacom.ciphering;

import java.math.BigInteger;
import java.util.StringTokenizer;

/**	This is the keypair object used to construct a key object to the RSA object, which implements the RSA encription algorithm.
		This object is generated by an RSAKeyPairGenerator.
		This object consists of two parts, a public and a private key.
		@see RSAKey
		@see RSAKeyPairGenerator
		@see RSA
*/

public class RSAKeyPair {

	private RSAKey rsaPrivateKey;
	private RSAKey rsaPublicKey;

/** 	Constructs a new RSAKeyPair object. This method is normally called by program, if the intension is to compose a keypair of two keys.
		@param in_rsaPrivateKey this includes the private part of the RSAKeyPair
		@param in_rsaPublicKey this includes the public part of the RSAKeyPair
*/	
	
	public RSAKeyPair(RSAKey in_rsaPrivateKey, RSAKey in_rsaPublicKey) {

		rsaPrivateKey=in_rsaPrivateKey;
		rsaPublicKey=in_rsaPublicKey;

	}
	
/** 	Constructs a new RSAKeyPair object. This method is normally called by the AESKeyGeneratorprogram.
		@param in_modulus this includes the modulus part of both RSAKeys
		@param in_privateExponent this includes the private exponent part of the private RSAKey
		@param in_publicExponent this includes the public exponent part of the public RSAKey
*/	
	
	public RSAKeyPair(BigInteger in_modulus, BigInteger in_privateExponent, BigInteger in_publicExponent) {

		rsaPrivateKey=new RSAKey(in_modulus, in_privateExponent);
		rsaPublicKey=new RSAKey(in_modulus, in_publicExponent);

	}

/** 	Constructs a new RSAKey object. This method is normally called when a serialized form of the RSAKey is given, this reconstructs the object.
		@param save this includes the serialized form of the RSAKey
		@thorws LoadKeyException this occurs, when the input value is not recognized as an RSAKey
*/	
	
	public RSAKeyPair(String save) throws LoadKeyException {
	
		try {
			StringTokenizer stringTokenizer=new StringTokenizer(save);

			rsaPrivateKey=new RSAKey(stringTokenizer.nextToken()+" "+stringTokenizer.nextToken());
			rsaPublicKey=new RSAKey(stringTokenizer.nextToken()+" "+stringTokenizer.nextToken());
		}
		catch (Exception e) {
			throw new LoadKeyException("RSAKeyPair: loading error: "+e);
		}

	}
	
/**	Returns the private key part of the RSAKey.
		@return the private key part of the RSAKey
*/	
	
	public RSAKey getPrivate() {

		return rsaPrivateKey;

	}

/**	Returns the public key part of the RSAKey.
		@return the public key part of the RSAKey
*/	
	
	public RSAKey getPublic() {

		return rsaPublicKey;

	}
	
/**	Returns the serialized String representation of the RSAKeyPair.
		@return the serialized form of the RSAKeyPair
*/
	
	public String toString() {
	
		return new String(rsaPrivateKey.toString()+" "+rsaPublicKey.toString());
	
	}

}
