/************************************************************************
*
* Copyright (C) 2001 by 
* Kerenyi Kristof, Toth Gergely
*
* Team Monica Javacom, Package version 0.2
*
* Report any comments to javacom@tg.sch.bme.hu
* 
* Available under the GPL.
* 
* For more details about the copyright terms and conditions read the
* GNU Public License (GPL) available under www.gnu.org/copyleft/gpl.txt.
* 
*********************************************************************** */


package com.monica.javacom.interfaces;

import com.monica.javacom.interfaces.*;

/** This interface is responsible for the configuration of objects in the
    MJC layer hierarchy. Configuration sources can be of any kind, 
    the main thing is that the classes can get configuration data 
    of common way.
*/    

public interface MJCConfiguration {

  /** Retuns an int configuration value for the specified configuration id.
      @param String id: the required configuration id
      @return int: the configuration int matching the configuration id
      @exception Exception: if the id is invalid or the id doesn't represent an 
        int value
  */	
  public int getInt(String id) throws Exception;
  
  /** Returns a boolean configuraton value for the specified configuration id.
      @param String id: the required configuration id
`      @return boolean: the configuration boolean matching the configuration id
      @exception Exception: if the id is invalid or the id doesn't represent a
        boolean value
  */	
  public boolean getBoolean(String id) throws Exception;

  /** Returns a String configuraton value for the specified configuration id.
      @param String id: the required configuration id
      @return String: the configuration String matching the configuration id
      @exception Exception: if the id is invalid or the id doesn't represent a
        String value
  */	
  public String getString(String id) throws Exception;
  
  /** Returns an int configuraton value for the specified configuration id.
      Should call the getInt(String) method of this interface and if there
      was an exception, returns the specified default value.
      @param String id: the required configuration id
      @param int def: the specified default value
      @return int: the configuration int matching the configuration id
        or if there was an exception then the default int
  */	
  public int getInt(String id, int def);

  /** Returns a boolean configuraton value for the specified configuration id.
      Should call the getBoolean(String) method of this interface and if there
      was an exception, returns the specified default value.
      @param String id: the required configuration id
      @param boolean def: the specified default value
      @return boolean: the configuration boolean matching the configuration id
        or if there was an exception then the default boolean
  */	
  public boolean getBoolean(String id, boolean def);

  /** Returns a String configuraton value for the specified configuration id.
      Should call the getString(String) method of this interface and if there
      was an exception, returns the specified default value.
      @param String id: the required configuration id
      @param boolean String: the specified default value
      @return boolean: the configuration String matching the configuration id
        or if there was an exception then the default String
  */	
  public String getString(String id, String def);

  /** Useable if String possible values in the configuration source 
      should be mapped into ints as configuration values.
      If there is a problem retrieving the int returned, the default
      value will be returned.
      @param String id: the required configuration id
      @param String[] possibilities: possible Strings acceptable in the
        configuration source
      @param int[] values: int values matching the possible Strings
      @param int def: the dafault int that should be returned in case of
        errors
      @return int: the int value matching the found possibility String of
        the def int
  */  
  public int getIntFromStrings(String id, String[] possibilities, int[] values, int def);
  
  /** Returns the MJC name of the MJCConfiguration.
      @return String: the MJC name of the MJCConfiguration
  */      
  public String getConfigurationName();
  
  /** Returns the MJC version of the MJCConfiguration.
      @return String: the MJC version of the MJCConfiguration
  */      
  public String getConfigurationVersion();
  
}
