/************************************************************************
*
* Copyright (C) 2001 by 
* Kerenyi Kristof, Toth Gergely
*
* Team Monica Javacom, Package version 0.2
*
* Report any comments to javacom@tg.sch.bme.hu
* 
* Available under the GPL.
* 
* For more details about the copyright terms and conditions read the
* GNU Public License (GPL) available under www.gnu.org/copyleft/gpl.txt.
* 
*********************************************************************** */


package com.monica.javacom.interfaces;

import com.monica.javacom.interfaces.*;

/** Implements the source part of the read functionality in the
    MJC layer hierarchy. MJCReadable is always the source of data for
    an MJCReader. Reading in the MJC layer hierarchy is asynchronous.
    If there is data available from the MJCReadable, the readEvent of
    the MJCReader is called. Which then can read through the getInput
    method of the MJCReadable. Data during the time between the readEvent 
    and getInput will be buffered.
*/    
public interface MJCReadable {

  /** Returns the MJC name of the MJCReadable.
      @return String: the MJC name of the MJCReadable
  */      
  public String getReadableName();
  
  /** Returns the MJC version of the MJCReadable.
      @return String: the MJC version of the MJCReadable
  */      
  public String getReadableVersion();
  
  /** Returns the number of bytes that are available for read out from
      this MJCReadable.
      @return int: the number of bytes available for read out
  */      
  public int getAvailable();
  
  /** Returns the contents of the read buffer from this MJCReadable.
      @return String: the contents of the read buffer
  */      
  public String getInput();
  
  /** Returns wether the MJCReadable is still connected to its source.
      @return boolean: wether the MJCReadable is still connected to its 
        source
  */	
  public boolean isReadableConnected();
  
  /** Sets the MJCReader to which the readEvents have to be sent.
      @param MJCReader reader: the MJCReader to which the readEvents
        have to be sent
  */	
  public void setReader(MJCReader reader);
  
  /** Returns the MJCReader to which readEvents will be sent.
      @return MJCReader: the MJCReader to which readEvents will be sent
  */      
  public MJCReader getReader();
  
}    