/************************************************************************
*
* Copyright (C) 2001 by 
* Kerenyi Kristof, Toth Gergely
*
* Team Monica Javacom, Package version 0.2
*
* Report any comments to javacom@tg.sch.bme.hu
* 
* Available under the GPL.
* 
* For more details about the copyright terms and conditions read the
* GNU Public License (GPL) available under www.gnu.org/copyleft/gpl.txt.
* 
*********************************************************************** */


package com.monica.javacom.interfaces;

import com.monica.javacom.interfaces.*;

/** Implements the destination part of the read functionality in the
    MJC layer hierarchy. MJCReader is always the destination of data from
    an MJCReadable. Reading in the MJC layer hierarchy is asynchronous.
    If there is data available from the MJCReadable, the readEvent of
    the MJCReader is called. Which then can read through the getInput
    method of the MJCReadable. Data during the time between the readEvent 
    and getInput will be buffered in the MJCReadable.
*/    
public interface MJCReader {

  /** Returns the MJC name of the MJCReader.
      @return String: the MJC name of the MJCReader
  */      
  public String getReaderName();
  
  /** Returns the MJC version of the MJCReader.
      @return String: the MJC version of the MJCReader
  */      
  public String getReaderVersion();
  
  /** Indicates that there is data available from the specified  
      MJCReadable.
      @param MJCReadable readable: there is data available from the
        readable
  */	
  public void readEvent(MJCReadable readable);
  
  /** Indicates that the source connection of the specified
      MJCReadable has been closed.
      @param MJCReadable readable: the MJCReadable whose source connection
        has been closed
  */	
  public void connectionClosedEvent(MJCReadable readable);
  
  /** Indicates that there was an error in the source connection
      of the specified MJCReadable.
      @param String errorDescription: the error message
      @param MJCReadable readable: the MJCReadable where the error
        occured
  */	
  public void errorEvent(String errorDescription, MJCReadable readable);  
  
  /** Sets the MJCReadable from which data has to be read.
      @param MJCReadable readable: the MJCReadable from which data has
        to be read
  */	
  public void setReadable(MJCReadable readable);
  
  /** Returns the MJCReadable from which data will be read.
      @return MJCReadable: the MJCReadable from which data will be read
  */      
  public MJCReadable getReadable();
  
}    