/************************************************************************
*
* Copyright (C) 2001 by 
* Kerenyi Kristof, Toth Gergely
*
* Team Monica Javacom, Package version 0.2
*
* Report any comments to javacom@tg.sch.bme.hu
* 
* Available under the GPL.
* 
* For more details about the copyright terms and conditions read the
* GNU Public License (GPL) available under www.gnu.org/copyleft/gpl.txt.
* 
*********************************************************************** */


package com.monica.javacom.interfaces;

import com.monica.javacom.interfaces.*;
import java.io.*;

/** Bottom level layer in the MJC layer hierarchy responsible for
    the basic connection between the client and server side. This
    layer has to ensure the transfer of the streams between the 
    two sides.
*/    

public interface MJCTransport extends MJCWriteable, MJCReadable, MJCConfigureable, Runnable {

  /** Returns the MJC name of the MJCTransport.
      @return String: the MJC name of the MJCTransport
  */      
  public String getTransportName();
  
  /** Returns the MJC version of the MJCTransport.
      @return String: the MJC version of the MJCTransport
  */      
  public String getTransportVersion();

  /** Initializes the MJCTransport as the server side. Clients
      can connect to the specified port.
      @param int port: the port where the clients can connect
      @exception IOException: if the server could not be started
  */  
  public void initAsServer(int port) throws IOException;
  
  /** Initializes the MJCTransport as the client side. This client
      will try to connect to the specified host and port.
      @param String host: the destination host
      @param int port: the destination port
      @exception IOException: if the client cannot connect to
        the specified host and port
  */
  public void initAsClient(String host, int port) throws IOException;
  
  /** Closes all connections of the MJCTransport.
  */  
  public void closeConnections();
  
  /** Generates a checksum for a String. 
      @param String: the String for which a checksum is needed
      @return String: the checksum
  */  
  public String checkSum(String s);
    
  /** Sets the MJCServerManager which will be notified if a client
      connects.
      @param MJCServerManager serverManager: the MJCServerManager
        that has to be notified if a client connects
  */	  
  public void setServerManager(MJCServerManager serverManager);
  
  /** Returns the MJCServerManager which will be notified if a client
      connects.
      @return MJCServerManager: the MJCServerManager which will
        be notified if a client connects
  */	
  public MJCServerManager getServerManager();
  
}
