/************************************************************************
*
* Copyright (C) 2001 by 
* Kerenyi Kristof, Toth Gergely
*
* Team Monica Javacom, Package version 0.2
*
* Report any comments to javacom@tg.sch.bme.hu
* 
* Available under the GPL.
* 
* For more details about the copyright terms and conditions read the
* GNU Public License (GPL) available under www.gnu.org/copyleft/gpl.txt.
* 
*********************************************************************** */


package com.monica.javacom.interfaces;

import com.monica.javacom.interfaces.*;

/** Implements the destination part of the write functionality in the
    MJC layer hierarchy. MJCWriteable is always the destination of data
    from the MJCWriter. Writing in the MJC layer hierarchy is synchronous.
    If the MJCWriter is willing to write, it calls one of the write
    methods of the MJCWriteable. The write will return after the data is 
    submitted to bottom layers. Data can be buffered by the MJCWriteable.
*/    
public interface MJCWriteable {

  /** Returns the MJC name of the MJCWriteable.
      @return String: the MJC name of the MJCWriteable
  */      
  public String getWriteableName();
  
  /** Returns the MJC version of the MJCWriteable.
      @return String: the MJC version of the MJCWriteable
  */      
  public String getWriteableVersion();
  
  /** Writes one single char. Writing is synchronous and can be
      buffered.
      @param char c: the char to be written
      @return boolean: wether the writing has been successful
  */      
  public boolean write(char c);
  
  /** Writes a String. Writing is synchronous and can be buffered.
      @param String s: the String to be written
      @return boolean: wether the writing has been successful
  */      
  public boolean write(String s);
  
  /** Writes a char array. Writing is synchronous and can be buffered.
      @param char[] c: the char array to be written
      @return boolean: wether the writing has been successful
  */   
  public boolean write(char[] c);
  
  /** Flushes the contents of the write buffer to bottom layers.
  */
  public void flush();
  
  /** Returns the error message of the last occured error. After
      returning it, the error message will be deleted and cannot
      be queried again.
      @return String: the last error message
  */  
  public String getLastWriteableError();
  
  /** Returns wether the MJCWriteable is connected to its target.
      @return boolean: wether the MJCWriteable is connected to
        its target
  */
  public boolean isWriteableConnected();
  
}    