/************************************************************************
*
* Copyright (C) 2001 by 
* Kerenyi Kristof, Toth Gergely
*
* Team Monica Javacom, Package version 0.2
*
* Report any comments to javacom@tg.sch.bme.hu
* 
* Available under the GPL.
* 
* For more details about the copyright terms and conditions read the
* GNU Public License (GPL) available under www.gnu.org/copyleft/gpl.txt.
* 
*********************************************************************** */


package com.monica.javacom.streams;

import com.monica.javacom.interfaces.*;
import com.monica.javacom.util.*;
import java.io.*;

/** Class for creating a link between an OutputStream and the MJC
    layer hierarchy. This class acts as a MJCReader, this means it 
    handles asynchronous readEvents from an MJCReadable, and what it
    reads, it forwards to an OuputStream. The writing to the OuputStream
    is not buffered.
*/

public class MJCReaderHasAOS implements MJCReader {

  private static final String NAME="MJCReaderHasAOS";
  private static final String VERSION="0.1";
  
  private MJCReadable readable;
  private OutputStream os;
  
  /** Constructor. The OutputStream has to be specified.
      @param OutputStream os: the OutputStream to which data has to 
        be forwarded
  */	     
  public MJCReaderHasAOS(OutputStream os) {
    this.os=os;
  }
  
  /** Returns the MJC name of the MJCReader.
      @return String: the MJC name of the MJCReader
  */      
  public String getReaderName() {
    return NAME;
  }
  
  /** Returns the MJC version of the MJCReader.
      @return String: the MJC version of the MJCReader
  */      
  public String getReaderVersion() {
    return VERSION;
  }
  
  /** Handles the asynchronous readEvents from the MJCReadable. Data
      read from the MJCReadable will be written on the OutputStream.
      @param MJCReadable readable: the MJCReadable from which the
        readEvent came
  */	
  public void readEvent(MJCReadable readable) {    
    String input=readable.getInput();
    try {
      byte[] b=input.getBytes();
      os.write(b);
    }
    catch (Exception e) {
      e.printStackTrace();
    }  	            
  }
  
  /** Handles the asynchronous connectionClosedEvents from the
      MJCReadable. The OutputStream will be closed.
      @param MJCReadable readable: the MJCReadable where the
        connectionClosedEvent occured
  */	
  public void connectionClosedEvent(MJCReadable readable) {
    try {
      os.close();
    }
    catch (Exception e) {
    }  
  }
  
  /** Handles the asynchronous errorEvent from the MJCReadable. 
      The OutputStream will be closed.
      @param String errorDescription: the error message
      @param MJCReadable readable: the MJCReadable where the error 
        occured
  */	
  public void errorEvent(String errorDescription, MJCReadable readable) {
    try {
      os.close();
    }
    catch (Exception e) {
    }  
  }
  
  /** Sets the MJCReadable from which data has to be read, this means, 
      which will send the readEvents.
      @param MJCReadable readable: the MJCReadable from which data has
        to be read
  */	
  public void setReadable(MJCReadable readable) {
    this.readable=readable;
  }            
  
  /** Queries the MJCReadable from which data will be read.
      @return MJCReadable: the MJCReadable from which data will be read
  */      
  public MJCReadable getReadable() {
    return readable;
  }      
}