/************************************************************************
*
* Copyright (C) 2001 by 
* Kerenyi Kristof, Toth Gergely
*
* Team Monica Javacom, Package version 0.2
*
* Report any comments to javacom@tg.sch.bme.hu
* 
* Available under the GPL.
* 
* For more details about the copyright terms and conditions read the
* GNU Public License (GPL) available under www.gnu.org/copyleft/gpl.txt.
* 
*********************************************************************** */


package com.monica.javacom.util;

import com.monica.javacom.interfaces.*;
import java.util.*;
import java.io.*;

/** This class implements the MJConfiguration interface to provide customization possibility
    for MJC classes. This class reads customization information from a file called MJC.conf,
    which has to be located in the current directory.<br><br>
    The configuration file can have the following stucure:<br>
    <ul>
      <li>lines beginning with # are recognized as comments and therefore ignored
      <li>lines not beginning with # are recognized as configuration lines<br><br>
        configuration lines have the following structure:<br>
        <pre>keyword=value</pre>
        Values can be Strings, ints, and booleans. Booleans are represented with the
        strings "true" and "false". These values can be referenced int he get methods
        of the MJCConfiguration with the id matching the keyword.
    </ul>
*/
public class MJCFileConfiguration extends MJCInputStreamConfiguration {

  // constants
  private static final String defaultConfFileName="MJC.conf";

  private static final String NAME="MJCFileConfiguration";
  private static final String VERSION="0.1";

  /** Sets the MJCConfiguration for this object.
      @param MJCConfiguration configuration: the MJCConfiguration
        object for the customization
  */
  public String getConfigurationName() {
    return NAME;
  }

  /** Returns the MJCConfiguration with which this object is customized.
      @return MJCConfiguration: the MJCConfiguration with which this
        object is customized
  */
  public String getConfigurationVersion() {
    return VERSION;
  }

  /** Default constructor.
  */
  public MJCFileConfiguration() {
    pre_init();
    try {
      iS=new FileInputStream(defaultConfFileName);
      post_init();
    }
    catch (Exception e) {
    }
  }
}