/************************************************************************
*
* Copyright (C) 2001 by 
* Kerenyi Kristof, Toth Gergely
*
* Team Monica Javacom, Package version 0.2
*
* Report any comments to javacom@tg.sch.bme.hu
* 
* Available under the GPL.
* 
* For more details about the copyright terms and conditions read the
* GNU Public License (GPL) available under www.gnu.org/copyleft/gpl.txt.
* 
*********************************************************************** */


package com.monica.javacom.window;

import com.monica.javacom.interfaces.*;
import java.awt.*;
import java.awt.event.*;

/** Class for providing a framwork with AWT methods for the MJCVirtualDisplay and
    MJCVirtualInput implementing classes.<br><br>
    Configureable values:
    <ul>
      <li><b>windowTitle</b>: the window title of the client side
    </ul>
*/
public class MJCAWTWindow extends Frame implements MJCWindow {

  MJCVirtualDisplay content;
  MJCConfiguration configuration;
  MJCCloser closer;

  private static final String NAME="MJCAWTWindow";
  private static final String VERSION="0.1";

  private static final String CONF_WINDOW_TITLE="windowTitle";
  private static final String CONF_DEF_WINDOW_TITLE="MONICA JavaCom Terminal";

  /** Default constructor. The MJCVirtualDisplay output visualization, the MJCConfiguration customization
      and a KeyListener has to be specified.
      @param MJCVirtualDisplay content: output visualization
      @param MJCConfiguration configuration: customization
      @param KeyListener kl: the keyboard event handler
  */
  public MJCAWTWindow(MJCVirtualDisplay content, MJCConfiguration configuration, KeyListener kl) {

    super(configuration.getString(CONF_WINDOW_TITLE, CONF_DEF_WINDOW_TITLE));

    this.content=content;
    this.configuration=configuration;

    Dimension d=((Canvas)content).getSize();
    ((Canvas)content).addKeyListener(kl);
    addKeyListener(kl);
    add((Canvas)content);
    setBackground(((Canvas)content).getBackground());
//    setSize(d);
    setSize(new Dimension(d.width+20, d.height+40));
  }

  /** Returns the MJC name of the MJCWindow.
      @return String: the MJC name of the MJCWindow
  */
  public String getWindowName() {
    return NAME;
  }

  /** Returns the MJC version of the MJCWindow.
      @return String: the MJC version of the MJCWindow
  */
  public String getWindowVersion() {
    return VERSION;
  }

  /** Sets the MJCConfiguration for this object.
      @param MJCConfiguration configuration: the MJCConfiguration
        object for the customization
  */
  public void setConfiguration(MJCConfiguration configuration) {
    this.configuration=configuration;
  }

  /** Returns the MJCConfiguration with which this object is customized.
      @return MJCConfiguration: the MJCConfiguration with which this
        object is customized
  */
  public MJCConfiguration getConfiguration() {
    return configuration;
  }

  /** Sets the MJCCloser responsible for closing of the client
      side application upon user request.
      @param MJCCloser closer: the MJCCloser reponsible for the
        closing of the client side application upon user request
  */
  public void setCloser(MJCCloser closer) {
    this.closer=closer;
    addWindowListener(new MJCAWTWindowWindowCloser(closer, this));
  }

  /** Returns the MJCCloser responsible for the closing of the
      client side application upon user request.
      @return MJCCloser: the MJCCloser responsible for the closing
        of the client side application upon user request
  */
  public MJCCloser getCloser() {
    return closer;
  }

}

/** Class for processing window close mouse events.
*/
class MJCAWTWindowWindowCloser extends WindowAdapter {
  MJCCloser closer;
  Frame window;

  /** Constructor.
      @param MJCCloser closer: the application closer object
      @param Frame window: the main window to be closed
  */
  MJCAWTWindowWindowCloser(MJCCloser closer, Frame window) {
    this.closer=closer;
    this.window=window;
  }

  /** Method processing the window closing request.
      @param WindowEvent e: the generated WindowEvent
  */
  public void windowClosing(WindowEvent e) {
    window.setVisible(false);
    window.dispose();
    closer.closeApplication();
    System.exit(0);
  }
}

