/************************************************************************
*
* Copyright (C) 2001 by 
* Kerenyi Kristof, Toth Gergely
*
* Team Monica Javacom, Package version 0.2
*
* Report any comments to javacom@tg.sch.bme.hu
* 
* Available under the GPL.
* 
* For more details about the copyright terms and conditions read the
* GNU Public License (GPL) available under www.gnu.org/copyleft/gpl.txt.
* 
*********************************************************************** */


package com.monica.javacom.window;

import com.monica.javacom.interfaces.*;
import com.monica.javacom.transport.*;
import com.monica.javacom.ciphering.*;
import com.monica.javacom.manager.*;
import com.monica.javacom.protocol.*;
import com.monica.javacom.terminal.*;
import com.monica.javacom.virtualinput.*;
import com.monica.javacom.virtualdisplay.*;
import com.monica.javacom.window.*;
import com.monica.javacom.application.*;
import com.monica.javacom.util.*;

import java.io.*;
import java.awt.*;
import java.awt.event.*;
import java.applet.*;

public class MJCAppletWindow extends Applet implements MJCWindow {

  MJCVirtualDisplay content;
  MJCConfiguration configuration;
  MJCCloser closer;

  private static final String NAME="MJCAppletWindow";
  private static final String VERSION="0.1";

  private static final String CONF_WINDOW_TITLE="windowTitle";
  private static final String CONF_DEF_WINDOW_TITLE="MONICA JavaCom Terminal";

  public void init() {

    MJCConfigureable[] reconf=new MJCConfigureable[6];

    MJCConfiguration configuration=new MJCFileConfiguration();
    MJCTransport transport=new MJCTCPTransport();
    MJCCiphering ciphering=new MJCBasicCiphering(false);
    MJCManager manager=new MJCManager();
    MJCProtocol protocol=new MJCTelnetProtocol();
    MJCTerminal terminal=new MJCVT220Terminal();
    MJCVirtualDisplay display=new MJCAWTDisplay(configuration);
    MJCVirtualInput input=new MJCKeyListener();
    reconf[0]=transport;
    reconf[1]=ciphering;
    reconf[2]=terminal;
    reconf[3]=display;
    reconf[4]=input;
    reconf[5]=protocol;

    transport.setReader(ciphering);
    transport.setConfiguration(configuration);

    ciphering.setReadable(transport);
    ciphering.setReader(manager);
    ciphering.setWriteable(transport);
    ciphering.setConfiguration(configuration);

    manager.setReadable(ciphering);
    manager.setTransport(transport);
    manager.setWriteable(ciphering);
    manager.setReader(protocol);
    manager.setConfiguration(configuration);
    manager.setReconfigureable(reconf);

    protocol.setReadable(manager);
    protocol.setWriteable(manager);
    protocol.setReader(terminal);
    protocol.setConfiguration(configuration);

    terminal.setReadable(protocol);
    terminal.setConfiguration(configuration);
    terminal.setWriteable(protocol);
    terminal.setVirtualDisplay(display);

    display.setConfiguration(configuration);

    setConfiguration(configuration);
    setCloser(manager);

    input.setConfiguration(configuration);
    input.setWriteable(terminal);

    Dimension d=((Canvas)display).getSize();
    ((Canvas)display).addKeyListener((KeyListener)input);
    addKeyListener((KeyListener)input);
    add((Canvas)display);
    setBackground(((Canvas)display).getBackground());
    setSize(new Dimension(d.width+20, d.height+40));

    display.clear();
    display.setCPos(0,0);
    display.addS("Running...");
    display.newLine();
    display.setCPosX(0);
    display.refresh();

    String host=new String("tg.sch.bme.hu");
    String port=new String();
    int iPort=3000;
    try {
      host=getParameter("host");
      port=getParameter("port");
      iPort=Integer.parseInt(port);
    }
    catch (Exception e) {
    }

    try {
      transport.initAsClient(host,iPort);
    }
    catch (Exception e) {
      display.clear();
      display.setCPos(0,0);
      display.addS("Connection to the server could not be established. Reason: "+e.toString());
      display.refresh();
    }
  }

  /** Returns the MJC name of the MJCWindow.
      @return String: the MJC name of the MJCWindow
  */
  public String getWindowName() {
    return NAME;
  }

  /** Returns the MJC version of the MJCWindow.
      @return String: the MJC version of the MJCWindow
  */
  public String getWindowVersion() {
    return VERSION;
  }

  /** Sets the MJCConfiguration for this object.
      @param MJCConfiguration configuration: the MJCConfiguration
        object for the customization
  */
  public void setConfiguration(MJCConfiguration configuration) {
    this.configuration=configuration;
  }

  /** Returns the MJCConfiguration with which this object is customized.
      @return MJCConfiguration: the MJCConfiguration with which this
        object is customized
  */
  public MJCConfiguration getConfiguration() {
    return configuration;
  }

  /** Sets the MJCCloser responsible for closing of the client
      side application upon user request.
      @param MJCCloser closer: the MJCCloser reponsible for the
        closing of the client side application upon user request
  */
  public void setCloser(MJCCloser closer) {
    this.closer=closer;
//    addWindowListener(new MJCAWTWindowWindowCloser(closer, this));
  }

  /** Returns the MJCCloser responsible for the closing of the
      client side application upon user request.
      @return MJCCloser: the MJCCloser responsible for the closing
        of the client side application upon user request
  */
  public MJCCloser getCloser() {
    return closer;
  }

}